#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2019-05-13 20:51:13
# @Author  : Your Name (you@example.org)
# @Link    : http://example.org
# @Version : $Id$

import os,sys
import sympy




#kprice:开仓价格,dk:开仓方向,gg:杠杆倍数,qplv:强平保证金率
def okexQP(kprice,dk,num = 1.0,gg = 20.0,qplv = 0.2):
    if type(kprice) == float and kprice > 1.0 and (dk == 1 or dk == -1):
        kp = kprice         #开仓价
        mz = 100.0          #定单面值为100美元
        kbzj = num*(mz/kp)/gg   #保证金数量
        x = sympy.symbols('x')
        wsx = dk*(((mz/kp)*(x-kp))/x)/(mz/(kp*gg))*kbzj     #未实现盈亏
        out = sympy.solve( ((kbzj + wsx)*kp*gg/(mz*num)) - qplv,x)    #计算结果
        print(out)
        print(type(out),len(out))
        pout = out[0]
        shylv = dk*(((mz/kp)*(pout-kp))/pout)/(mz/(kp*gg))
        wsx_out = shylv*kbzj
        bzjv = 1.0 + shylv
        dicout = {'kbzj':kbzj,'qpPrice':pout,'wsx':wsx_out,'sylv':shylv,'bzjv':bzjv}
        return dicout
    else:
        return {}


#kplist:开仓价格和数量
def okexQP_Mutil(kplist,dk,gg = 20.0,qplv = 0.20):
    kbzj_all = 0.0   #保证金数量
    mz = 100.0          #定单面值为100美元
    # kp = kprice         #开仓价    
    x = sympy.symbols('x')
    wsx_all = 0.0
    k_all = 0.0
    num_all = 0.0
    minprice = 0.0
    maxprice = 0.0
    for i,v in enumerate(kplist):
        kp = v[0]
        num = v[1]
        kbzj = num*(mz/kp)/gg   #保证金数量
        kbzj_all += kbzj
        k_all += kp*num
        num_all += num
        wsx = dk*(((mz/kp)*(x-kp))/x)/(mz/(kp*gg))*kbzj     #未实现盈亏
        wsx_all += wsx
        if maxprice == 0.0 or kp > maxprice:
            maxprice = kp
        if minprice == 0.0 or kp < minprice:
            minprice = kp
    kp_all = k_all/num_all
    out = sympy.solve( ((kbzj_all + wsx_all)*kp_all*gg/(mz*num_all)) - qplv,x)    #计算结果
    # print(out)
    # print(type(out),len(out))
    pout = out[0]
    shylv = dk*(((mz/kp_all)*(pout-kp_all))/pout)/(mz/(kp_all*gg))
    wsx_out = shylv*kbzj_all
    bzjv = 1.0 + shylv
    outpercent = 0
    if dk < 0:
        outpercent = abs(pout - minprice)*100/minprice
    elif dk > 0:
        outpercent = abs(pout - maxprice)*100/maxprice
    dicout = {'kbzj':kbzj_all,'qpPrice':pout,'wsx':wsx_out,'sylv':shylv,'bzjv':bzjv,'pprice':kp_all,'maxpercent':outpercent}
    return dicout


def addNextPrice(plists,dk):
    dktype = 1
    if dk < 0:
        dktype = -1
    minput = []
    for i,v in enumerate(plists):
        minput.append([v,1])
    mtmp = okexQP_Mutil(minput, dktype)
    plists.append(mtmp['qpPrice'])
    return mtmp['kbzj'] #反回开仓保证金

def mutilPrice(kprice,dp):
    out = []
    if dp > 1:
        count = dp
        tmp = okexQP(float(kprice),1)
        # {'bzjv': 0.200000000000000, 'wsx': -0.000453001132502831, 'qpPrice': 8490.38461538462, 'sylv': -0.800000000000000, 'kbzj': 0.000566251415628539}
        # print(tmp)
        qpprice = tmp['qpPrice']
        tmplist = [kprice]
        tmplist.append(qpprice)
        kbzj = 0.0 #保证金
        count -= 1
        while count >0:
            kbzj = addNextPrice(tmplist,1)
            count -= 1
        # print(tmplist)
        return tmplist,kbzj
    elif dp < 0:
        count = dp
        tmp = okexQP(float(kprice),-1)
        qpprice = tmp['qpPrice']
        tmplist = [kprice]
        tmplist.append(qpprice)
        kbzj = 0.0 #保证金
        count += 1
        while count <0:
            kbzj = addNextPrice(tmplist,-1)
            count += 1
        # print(tmplist)
        return tmplist,kbzj #保证金
    else:
        return [],None

def main(kprice,dk):
    if dk > 1 or dk < -1:
        out = mutilPrice(float(kprice),int(dk))
        print(out)
    else:
        out = okexQP(float(kprice),int(dk))
        print(out)
def test():
    # out = okexQP(8148,1)
    # print(out)
    # out = okexQP_Mutil([[7310.1,4],[7351.83,3],[7400.86,3],[7460,3],[7534,2],[7635.48,2],[7788,1],[8100,1]], 1)
    # out = okexQP_Mutil([[7310.1,1],[7572.83,8]], 1)
    
    out = mutilPrice(8848.0, 3)

    print(out)
#测试
if __name__ == '__main__':
    args = sys.argv
    fpth = ''
    if len(args) == 3 :
        main(float(args[1]), int(args[2]))
    else:
        print "请加上开仓价，开仓方向，-1为空仓，1为多仓"
    # test()
    



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-28 16:28:50
# @Author  : Your Name (you@example.org)
# @Link    : http://example.org
# @Version : $Id$

import os,sys

import json
# import timetool
from . import timetool

if sys.version_info > (3,0):
    def cmp(a,b):
        import operator
        return operator.eq(a,b)


#获取脚本路径
def cur_file_dir():
    pathx = sys.argv[0]
    tmppath,_file = os.path.split(pathx)
    if cmp(tmppath,'') == 0:
        tmppath = sys.path[0]
    #判断为脚本文件还是py2exe编译后的文件，如果是脚本文件，则返回的是脚本的目录，如果是py2exe编译后的文件，则返回的是编译后的文件路径
    if os.path.isdir(tmppath):
        return tmppath
    elif os.path.isfile(tmppath):
        return os.path.dirname(tmppath)
    
#获取父目录
def GetParentPath(strPath):
    if not strPath:
        return None;
    lsPath = os.path.split(strPath);
    if lsPath[1]:
        return lsPath[0];
    lsPath = os.path.split(lsPath[0]);
    return lsPath[0];

#for python3
def cmp(a,b):
    return ((a>b)-(a<b))

#获取目录下的所有类型文件
def getAllExtFile(pth,fromatx = ".erl"):
    jsondir = pth
    jsonfilelist = []
    for root, _dirs, files in os.walk(jsondir):
        for filex in files:          
            #print filex
            name,text = os.path.splitext(filex)
            if cmp(text,fromatx) == 0:
                jsonArr = []
                rootdir = pth
                dirx = root[len(rootdir):]
                pathName = dirx +os.sep + filex
                jsonArr.append(pathName)
                (newPath,_name) = os.path.split(pathName)
                jsonArr.append(newPath)
                jsonArr.append(name)
                jsonfilelist.append(jsonArr)
            elif fromatx == ".*" :
                jsonArr = []
                rootdir = pth
                dirx = root[len(rootdir):]
                pathName = dirx +os.sep + filex
                jsonArr.append(pathName)
                (newPath,_name) = os.path.split(pathName)
                jsonArr.append(newPath)
                jsonArr.append(name)
                jsonfilelist.append(jsonArr)
    return jsonfilelist


#获取一个目录下的所有子目录路径
def getAllDirs(spth):
    files = getAllExtFile(spth,'.*')
    makedirstmp = []
    isOK = True
    # 分析所有要创建的目录
    for d in files:
        if d[1] != '/' and (not d[1] in makedirstmp): #创建未创建的目录层级
            tmpdir = d[1][1:]
            tmpleves = tmpdir.split('/')
            alldirs = getAllLevelDirs(tmpleves)
            for dtmp in alldirs:
                if not dtmp in makedirstmp:
                    makedirstmp.append(dtmp)
    return makedirstmp
#获取目录下的所有文件路径
def getAllFiles(spth,fromatx = '.*'):
    files = getAllExtFile(spth,fromatx)
    makedirstmp = []
    isOK = True
    # 分析所有要创建的目录
    for d in files:
        makedirstmp.append(d[0])
    return makedirstmp


def isFile(filename):
    try:
        with open(filename) as f:
            return True
    except IOError:
        return False

def finddir(arg,dirname,filenames):
    name,text = os.path.split(dirname)
    dirnametmp = str(dirname)
    if text and text[0] == '.':
        print(dirname)
        print(filenames)
        os.system('rm -r %s'%(dirname))
        return
    elif filenames:
        for f in filenames:
            if f[0] == '.' and isFile(dirname + f):
                fpthtmp = dirname + f
                if f.find(' '):
                    nf = f.replace(' ','\ ')
                    fpthtmp = dirname + nf
                print(dirname + f)
                os.system('rm  %s'%(fpthtmp))

#删除所有pth目录下的所有"."开头的文件名和目录名
def removeProjectAllHideDir(pth):
    alldirs = getAllDirs(pth)
    if not ('/' in alldirs):
        alldirs.append('/')
    for d in alldirs:
        tmpth = pth + d
        os.path.walk(tmpth, finddir, 0)


#获取一个路径中所包含的所有目录及子目录
def getAllLevelDirs(dirpths):
    dirleves = []
    dirtmp = ''
    for d in dirpths:
        dirtmp += '/' + d
        dirleves.append(dirtmp)
    return dirleves

#在outpth目录下创建ndir路径中的所有目录，是否使用决对路径
def makeDir(outpth,ndir):
    tmpdir = ''
    if ndir[0] == '/':
        tmpdir = outpth + ndir
    else:
        tmpdir = outpth + '/' + ndir
    print(tmpdir)
    if not os.path.exists(tmpdir):
        os.mkdir(tmpdir)

# 创建一个目录下的所有子目录到另一个目录
def createDirs(spth,tpth):
    files = getAllExtFile(spth,'.*')
    makedirstmp = []
    isOK = True
    # 分析所有要创建的目录
    tmpfpth = fpth
    for d in files:
        if d[1] != '/' and (not d[1] in makedirstmp): #创建未创建的目录层级
            tmpdir = d[1][1:]
            tmpleves = tmpdir.split('/')
            alldirs = getAllLevelDirs(tmpleves)
            for dtmp in alldirs:
                if not dtmp in makedirstmp:
                    makeDir(tpth,dtmp)
                    makedirstmp.append(dtmp)

# 替换文件名
def replaceFileName(path,sname,replaceStr,tostr):
    a = sname
    tmpname = a.replace(replaceStr, tostr)
    outpath = path + tmpname
    oldpath = path + sname
    cmd = "mv %s %s"%(oldpath,outpath)
    print(cmd)
    os.system("mv %s %s"%(oldpath,outpath))

# 替换目录下的文件名中某个字符串为其他字符串
def renameDir(sdir,replacestr,tostr,exittype):
    files = getAllExtFile(sdir,fromatx = exittype)
    allfilepath = []
    for f in files:
        tmppath = sdir + f[1]
        filename = f[2] + exittype
        allfilepath.append([tmppath,filename])
    for p in allfilepath:
        replaceFileName(p[0], p[1], replacestr, tostr)


def getFileNameFromPath(fpth):
    tmp = fname.split('/')[-1]
    fname = tmp.split('.')[0]
    return fname



def main():
    pass
    # print sntimes
#测试
if __name__ == '__main__':
    main()
    



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import time
import datetime
import sys
# loctim = time.localtime()
# #time.struct_time(tm_year=2015, tm_mon=8, tm_mday=2, tm_hour=12, tm_min=16, tm_sec=47, tm_wday=6, tm_yday=214, tm_isdst=0)
# sendmsg = str(loctim.tm_mon) + '_' +  str(loctim.tm_mday) + '_' + str(loctim.tm_hour) + '_' + str(loctim.tm_min) + '_' + str(loctim.tm_sec)

# print sendmsg


# datex = time.localtime(1459179579)
# sendmsg = str(datex.tm_mon) + '.' +  str(datex.tm_mday) + '_' + str(datex.tm_hour) + ':' + str(datex.tm_min) + ':' + str(datex.tm_sec)
# print sendmsg


# a = [1,2,3,6]
# b = [5,9,10]
# a = a + b
# print a

# print "aa", time.time()
# print time.localtime(time.time() + 60 *3)




def datetime2timestamp(dt, convert_to_utc=False):
    ''' Converts a datetime object to UNIX timestamp in milliseconds. '''
    if isinstance(dt, datetime.datetime):
        if convert_to_utc: # 是否转化为UTC时间
            dt = dt + datetime.timedelta(hours=-8) # 中国默认时区
        timestamp = datetime.timedelta.total_seconds(dt - datetime.datetime(1970,1,1))
        
        if sys.version_info > (3,1):
            return int(timestamp)
        elif sys.version_info <= (2,7):
            return long(timestamp)
    return dt

def timestamp2datetime(timestamp, convert_to_local=False):
    ''' Converts UNIX timestamp to a datetime object. '''
    if sys.version_info.major >= 3 and sys.version_info.minor >= 1:
        if isinstance(timestamp, (int, int, float)):
            dt = datetime.datetime.utcfromtimestamp(timestamp)
            if convert_to_local: # 是否转化为本地时间
                dt = dt + datetime.timedelta(hours=8) # 中国默认时区
            return dt
        return timestamp
    else:
        if isinstance(timestamp, (int, long, float)):
            dt = datetime.datetime.utcfromtimestamp(timestamp)
            if convert_to_local: # 是否转化为本地时间
                dt = dt + datetime.timedelta(hours=8) # 中国默认时区
            return dt
        return timestamp

def timestamp_utc_now():
    return datetime2timestamp(datetime.datetime.utcnow())

#获取当前时间戳
def getNowDate(ptime = None):
    if ptime:
        return timestamp2datetime(int(ptime),True)
    return timestamp2datetime(int(time.time()),True)

#获取今天的日期
def getDateDay():
    loctim = time.localtime()
    #time.struct_time(tm_year=2015, tm_mon=8, tm_mday=2, tm_hour=12, tm_min=16, tm_sec=47, tm_wday=6, tm_yday=214, tm_isdst=0)
    sendmsg = str(loctim.tm_year) + '_' + str(loctim.tm_mon) + '_' +  str(loctim.tm_mday)
    return sendmsg

#日期转为时间戳
def getDateStructWithSec(t):
    tmp = time.localtime(int(t))
    return tmp

#时间戳转为时间结构体
def makeSecTimeWithStructTime(structtime):
    timetmp = time.mktime(structtime)
    return timetmp

#年_月_日转为时间结构体
def getStruceTimeWithStrDate(strdate):
    timex = time.strptime(strdate, '%Y_%m_%d')
    return timex


#获取date的下一天日期,date格式:年_月_日
def getNextDayDate(date):
    structtime = getStruceTimeWithStrDate(date)
    sectime = makeSecTimeWithStructTime(structtime)
    onedaysec = 24*60*60
    sectime += onedaysec
    nextstruct = getDateStructWithSec(sectime)
    nextday = str(nextstruct.tm_year) + '_' + str(nextstruct.tm_mon) + '_' +  str(nextstruct.tm_mday)
    return nextday

def conventDayStrAdd_(pday,pjoin = '_'):
    ymds = pday.split(pjoin)
    y = ymds[0]
    m = ymds[1]
    d = ymds[2]
    if len(m) == 1:
        m = '0' + m
    if len(d) == 1:
        d = '0' + d
    out = y + pjoin + m + pjoin + d
    return out

def conventDayStrSub_(pday,pjoin = '_'):
    ymds = pday.split(pjoin)
    y = str(int(ymds[0]))
    m = str(int(ymds[1]))
    d = str(int(ymds[2]))
    out = y + pjoin + m + pjoin + d
    return out

#获取从某一天一直到今天的所有以天计算日期,年_月_日
def getDateDaysFromOneDate(startDate):
    startday = startDate
    today = getDateDay()
    startsec = getStruceTimeWithStrDate(startday)
    todaysec = getStruceTimeWithStrDate(today)
    if startsec >= todaysec:
        return []
    nextday = startday
    outdays =[]
    while today != nextday:
        nextday = getNextDayDate(nextday)
        outdays.append(nextday)
    return outdays
    # timetmp = time.struct_time(tm_year=toyear, tm_mon=tomon, tm_mday=today, tm_hour=0, tm_min=0, tm_sec=0, tm_wday=0, tm_yday=0, tm_isdst=0)
    # print timetmp



#UTC时间转本地时间
def utc2local(utc_st):
    '''UTC时间转本地时间（+8:00）'''
    now_stamp = time.time()
    local_time = datetime.datetime.fromtimestamp(now_stamp)
    utc_time = datetime.datetime.utcfromtimestamp(now_stamp)
    offset = local_time - utc_time
    local_st = utc_st + offset
    return local_st


#本地时间转UTC时间
def local2utc(local_st):
    '''本地时间转UTC时间（-8:00）'''
    time_struct = time.mktime(local_st.timetuple())
    utc_st = datetime.datetime.utcfromtimestamp(time_struct)
    return utc_st

#UTC格式的时间转换为本地时间
def utcStrToLocalTimeStr(tstr,UTC_FORMAT='%Y-%m-%dT%H:%M:%S.%fZ'):
    t1 = datetime.datetime.strptime(tstr, UTC_FORMAT)
    lt1 = utc2local(t1)
    return lt1.strftime("%Y-%m-%d %H:%M:%S")

def utcStrTimeToTime(tstr,UTC_FORMAT='%Y-%m-%dT%H:%M:%S.%fZ'):
    ldate = utcStrToLocalTimeStr(tstr,UTC_FORMAT)
    timeArray = time.strptime(ldate, "%Y-%m-%d %H:%M:%S")
    #转换成时间戳
    timestamp = time.mktime(timeArray)
    return timestamp
    
def strTimeToTime(tstr,FORMAT='%Y%m%d%H%M%S'):
    timeArray = time.strptime(tstr, FORMAT)
    #转换成时间戳
    timestamp = time.mktime(timeArray)
    return timestamp

if __name__ == '__main__':
    # print datetime.datetime.utcnow()
    # print timestamp_utc_now()
    print(timestamp2datetime(int(time.time()),True))

    print(getNowDate())

    # tmpdat = '2017_7_17'
    # print(getDateDaysFromOneDate(tmpdat))
    # outstr = timestamp2datetime(int(time.time() + 60 * 5),True)
    # print outstr


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-09 22:36:40
# @Author  : mage
# @Link    : http://woodcol.com
# @market. : https://fengmm521.taobao.com
# @Version : $Id$

from sys import version_info  
import pickle

def pythonVersion():
    return version_info.major,version_info.minor

#保存python对象到文件
def saveObjToFile(obj,fPth):
    f = open(fpth,'wb')
    pickle.dump(obj, f)
    f.close()

#从文件加载一个对象
def loadObjFromFile(fpth):
    f = open(fpth,'rb')
    obj = pickle.load(f)
    f.close()
    return obj

if __name__ == '__main__':
    print(pythonVersion())




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-09 22:36:40
# @Author  : mage
# @Link    : http://woodcol.com
# @market. : https://fengmm521.taobao.com
# @Version : $Id$

# from win32com.client import GetObject
import platform
import os
sysSystem = platform.system()


def getUUID():
    cmd = ""
    if sysSystem == 'Windows':  
        cmd = 'wmic csproduct get UUID'
    elif sysSystem == 'Darwin':
        cmd = "/usr/sbin/system_profiler SPHardwareDataType | fgrep 'UUID' | awk '{print $NF}'"
    elif sysSystem == 'Linux':
        cmd = "/usr/sbin/dmidecode -s system-uuid"
    output = os.popen(cmd)
    ostr = output.read()
    ostr = ostr.replace('\r','')
    ostrs = ostr.split('\n')
    uuid = ''
    for d in ostrs:
        tmpd = d.strip()
        if len(tmpd) < 20:
            continue
        else:
            uuid = tmpd
    return uuid

def main():
    uuid = getUUID()
    print(uuid)
if __name__ == '__main__':
    main()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import json


def saveListWithJson(datas,jsonpth):
    ostr = json.dumps(datas)
    f = open(jsonpth,'w')
    f.write(ostr)
    f.close()

def getListDataFromJsonFile(jpth):
    f = open(jpth,'r')
    jstr = f.read()
    f.close()
    datas = json.loads(jstr)
    return datas

def saveDicWithJson(dic,jsonpth):
    ostr = json.dumps(dic)
    f = open(jsonpth,'w')
    f.write(ostr)
    f.close()

def getDicDataFromJsonFile(jpth):
    f = open(jpth,'r')
    jstr = f.read()
    f.close()
    datas = json.loads(jstr)
    return datas

def saveListWithLineTxt(datas,txtpth):
    ostr = ''
    for d in datas:
        ostr += str(d) + '\n'
    ostr = ostr[:-1]
    f = open(txtpth,'w')
    f.write(ostr)
    f.close()

#获取A在B中的数量和坐标位置
def getAinBList(A,B):
    X = [A==B[i:i+len(A)] for i in range(0,len(B)-len(A)+1)]
    return X

#判断listB中是否包含A
def isAinB(A,B):
    # a = any([A==B[i:i+len(A)] for i in range(0,len(B)-len(A)+1)])
    X = [A==B[i:i+len(A)] for i in range(0,len(B)-len(A)+1)]
    return any(X)
#获取多维数组中的某一维数据，组成一个新数组
def getMutlListWithIndex(datas,idx = 0):
    vtmp = [x[idx] for x in datas]
    return vtmp

def subList(lis1,lis2):
    v1 = list(lis1)
    v2 = list(lis2)
    v = list(map(lambda x: x[0]-x[1], zip(v1, v2)))
    return v

def getListWithCSVFile(csvpth,isHeaveHand = False):
    outs = []
    f = open(csvpth,'r')
    lines = f.readlines()
    f.close()
    if isHeaveHand:
        lines = lines[1:]

    for l in lines:
        tmpl = l.replace('\n','')
        tmpl = tmpl.replace('\r','')
        tmps = tmpl.split(',')
        if len(tmps) > 0:
            outs.append(tmps)
    return outs

if __name__ == '__main__':
    pass
    v1 = [2.4,3.3,4.2,8.1]
    v2 = [1,2,1,4]
    v = subList(v1, v2)
    print(v)

    A = [4,6]
    B = [1,2,3,4,6,7,9]
    res = getAinBList(A, B)
    print(res)



#!/usr/bin/python
# -*- coding: utf-8 -*-
#创建SocketServerTCP服务器：

import socket
import sys

def client_program():
    host = socket.gethostname()  # as both code is running on same pc
    print('hostname',host)
    port = 9101  # socket server port number

    client_socket = socket.socket()  # instantiate
    client_socket.connect((host, port))  # connect to the server

    if hasattr(__builtins__, 'raw_input'): 
        inputstr = raw_input
    else:
        inputstr = input
    message = inputstr('prompt:')
    print(message)

    while message.lower().strip() != 'bye':
        client_socket.send(message.encode())  # send message
        data = client_socket.recv(1024).decode()  # receive response

        print('Received from server: ' + data)  # show in terminal

        message = inputstr(" -> ")  # again take input

    client_socket.close()  # close the connection


if __name__ == '__main__':
    client_program()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-09 22:36:40
# @Author  : Your Name (you@example.org)
# @Link    : http://example.org
# @Version : $Id$

import socket

def isNetOK(testserver):
    s=socket.socket()
    s.settimeout(3)
    try:
        status = s.connect_ex(testserver)
        if status == 0:
            s.close()
            return True
        else:
            return False
    except Exception as e:
        return False

def isNetChainOK(testserver=('www.baidu.com',443)):
    isOK = isNetOK(testserver)
    return isOK
    

def isNetUSAOK(testserver=('www.google.com',443)):
    isOK = isNetOK(testserver)
    return isOK
    
def isNetYouTubeOK(testserver=('www.youtube.com',443)):
    isOK = isNetOK(testserver)
    return isOK

def main():

    chinanet = isNetChainOK()
    print(chinanet)
    usanet = isNetUSAOK()
    print(usanet)
    youtubenet = isNetYouTubeOK()
    print(youtubenet)
    

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2017-12-28 16:28:50
# @Author  : Your Name (you@example.org)
# @Link    : http://example.org
# @Version : $Id$

import os,sys
from magetool import timetool
import numpy as np

#didx为数值在数据中的序号，用来取作均线计算的数据位
def getAverageData(datas,pAver = 3,didx = 4):
    #[1517536380000,142.443,142.443,142,142,3486,244.8654307]
    ##时间戳，开，高，低，收，交易量，交易量转化为BTC或LTC数量
    outs = []
    for n in range(len(datas)):
        d = datas[n]
        tmps = [d[0]]
        if n < pAver -1:
            dtmp = datas[0:n+1]
            vtmp = [x[didx] for x in dtmp]
            mean = np.mean(vtmp)
            tmps.append(mean)
        else:
            dtmp = datas[n - pAver+1:n+1]
            vtmp = [x[didx] for x in dtmp]
            mean = np.mean(vtmp)
            tmps.append(mean)
        outs.append(tmps)
    return outs

def subList(lis1,lis2):
    v1 = list(lis1)
    v2 = list(lis2)
    v = list(map(lambda x: x[0]-x[1], zip(v1, v2)))
    return v


def get_EMA(df,N,idx = 4):  
    emas = []
    for i in range(len(df)):  
        if i==0:  
            emas = [df[i][idx]]
        if i>0:  
            emastmp = (emas[-1] * (N-1.0) + df[i][idx] * 2.0)/(N+1.0)
            emas.append(emastmp)
    return emas  



def get_MACD(df,dshort = 12,dlong = 26,M = 9):
    a=get_EMA(df,dshort)  
    b=get_EMA(df,dlong)  
    DIF=subList(a, b) 

    DEA = []
    #print(df['diff'])  
    for i in range(len(df)):  
        if i==0:  
            # df.ix[i,'dea']=df.ix[i,'diff'] 
            DEA = [DIF[i]] 

        if i>0:  
            DEAtmp = (2 * DIF[i] + (M - 1) * DEA[i-1])/(M+1)
            DEA.append(DEAtmp)

    MACD = list(map(lambda x: (x[0]-x[1])*2, zip(DIF, DEA)))

    return DIF,DEA,MACD
    

def test():
    # openLong()
    print timetool.getNowDate()
    #1.buy,0.不操作，-1.sell



def getLastMacdType(macd):

    mtmps = macd[::-1]
    SXidx = -1
    JXidx = -1
    for i in range(len(mtmps)):
        if i > 0:
            if macd[i-1] >= 0 and macd[i] < 0:
                SXidx = i
            if macd[i-1] <= 0 and macd[i] > 0:
                JXidx = i

            if SXidx >= 0 and JXidx >= 0:
                break
    return SXidx,JXidx


def main():
    # k5d = read5MimKline()
    #['时间戳'，'开'，'高'，'低'，'收'，'交易量'，'交易量转化为BTC或LTC数量']
    kdatas = []
    # isUP = isClose(k1d)
    if not kdatas:
        return
    dif,dea,macd = get_MACD(kdatas)


    

#测试
if __name__ == '__main__':
    main()
    # test()



#!/usr/bin/python
# -*- coding: utf-8 -*-
#创建SocketServerTCP服务器：

import SocketServer
# from SocketServer import StreamRequestHandler

import os
import socket

myname = socket.getfqdn(socket.gethostname())
myaddr = socket.gethostbyname(myname)

print('selfip:%s'%(myaddr))
host = str(myaddr)


port = 9101
addr = (host,port)

class Servers(SocketServer.StreamRequestHandler):
    def handle(self):
        print('got connection from ',self.client_address)
        while True:
            try:  
                data = self.request.recv(1024)
            except EOFError:  
                print('接收客户端错误，客户端已断开连接,错误码:')
                print(EOFError )
                break
            except:  
                print('接收客户端错误，客户端已断开连接')
                break
            if not data: 
                break
            print('data len:%d'%(len(data)))
            print("RECV from ", self.client_address)
            print(data)
            self.request.send('aaa')

def startServer():
    server = SocketServer.ThreadingTCPServer(addr,Servers,bind_and_activate = False)
    server.allow_reuse_address = True   #设置IP地址和端口可以不使用客户端连接等待，并手动绑定服务器地址和端口，手动激活服务器,要不然每一次重启服务器都会出现端口占用的问题
    server.server_bind()
    server.server_activate()
    print('server started:')
    print(addr)
    server.serve_forever()
    
if __name__ == '__main__':
    startServer()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2016-12-07 09:28:00
# @Link    : http://fengmm521.blog.163.com
# @Version : $Id$
#这里使用pycrypto‎库
#按照方法:easy_install pycrypto‎
 
import os,sys
import base64
import requests

# from Crypto import Random
# from Crypto.Hash import SHA
# from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
# from Crypto.Signature import PKCS1_v1_5 as Signature_pkcs1_v1_5
# from Crypto.PublicKey import RSA
import rsa

# https://www.cnblogs.com/hhh5460/p/5243410.html

class prpcrypt():
    def __init__(self,mURL,mkeyPth,gkeyPth,isCreateGkey = True,isTest = False):
        self.mkeyPth = mkeyPth     #master公钥保存地址
        self.gkeyPth = gkeyPth     #本地密钥保存地址
        self.mURL = mURL           #master公钥请求地址，
        
        self.gprivate_pem = None
        self.gpublic_pem = None

        self.mpublic_pem = None

        self.isTest = isTest

        if isCreateGkey:
            #生成新的公私钥对
            self.createGhostKey()
            # self.saveGhostKeyToFile()
        else:
            self.readGhostKeyFromFile()
            if self.gprivate_pem == None or self.gpublic_pem == None:
                self.createGhostKey()
                self.saveGhostKeyToFile()
        self.masterKeyFromFile()

    def saveGhostKeyToFile(self):
        f = open(self.gkeyPth + '/gprivate.pem','w')
        if sys.version_info > (3,0):
            f.write(self.gprivate_pem.save_pkcs1().decode())
        else:
            f.write(self.gprivate_pem.save_pkcs1())
        f.close()
        f = open(self.gkeyPth + '/gpublic.pem','w')
        if sys.version_info > (3,0):
            f.write(self.gpublic_pem.save_pkcs1().decode())
        else:
            f.write(self.gpublic_pem.save_pkcs1())
        f.close()

    def saveMPubKeyToFile(self,fname,pemkeypkcs1):
        f = open(self.mkeyPth + os.sep + fname + '.pem','w')
        if sys.version_info > (3,0):
            f.write(pemkeypkcs1)
        else:
            f.write(pemkeypkcs1)
        f.close()

    def getGPubkey(self):
        if sys.version_info > (3,0):
            return self.gpublic_pem.save_pkcs1().decode()
        else:
            return self.gpublic_pem.save_pkcs1()

    def getKeyWithPKCS1(self,pemkeypkcs1):
        if sys.version_info > (3,0):
            return rsa.PrivateKey.load_pkcs1(pemkeypkcs1.encode())
        else:
            return rsa.PrivateKey.load_pkcs1(pemkeypkcs1)

    def readGhostKeyFromFile(self):
        pripth = self.gkeyPth + '/gprivate.pem'
        pubpth = self.gkeyPth + '/gpublic.pem'
        if os.path.exists(pripth) and os.path.exists(pubpth):
            f = open(pripth,'r')
            if sys.version_info > (3,0):
                self.gprivate_pem = rsa.PrivateKey.load_pkcs1(f.read().encode())
            else:
                self.gprivate_pem = rsa.PrivateKey.load_pkcs1(f.read())
            f.close()
            f = open(pubpth,'r')
            if sys.version_info > (3,0):
                self.gpublic_pem = rsa.PublicKey.load_pkcs1(f.read().encode())
            else:
                self.gpublic_pem = rsa.PublicKey.load_pkcs1(f.read())
            f.close()
        else:
            print('本地RSA密钥文件不存在，可以文件丢失，请重新生成...')

    #从文件读取交互对方的公钥
    def masterKeyFromFile(self):
        pubpth = self.mkeyPth + '/mpublic.pem'
        if os.path.exists(pubpth):
            f = open(pubpth,'r')
            if sys.version_info > (3,0):
                self.mpublic_pem = rsa.PublicKey.load_pkcs1(f.read().encode())
            else:
                self.mpublic_pem = rsa.PublicKey.load_pkcs1(f.read())
            f.close()
        else:
            self.mpublic_pem = self.requestMasterPubkey()
            if self.mpublic_pem != None:
                self.saveMasterPubkeyToFile()
        if self.mpublic_pem == None:
            print('未获取到交互对方公钥...')

    def saveMasterPubkeyToFile(self):
        pubpth = self.mkeyPth + '/mpublic.pem'
        f = open(pubpth,'w')
        if sys.version_info > (3,0):
            f.write(self.mpublic_pem.save_pkcs1().decode())
        else:
            f.write(self.mpublic_pem.save_pkcs1())
        f.close()
    #向服务器请求pubkey
    def requestMasterPubkey(self):
        if self.mURL[0:4] == 'http':
            rurl = self.mURL
            try:
                res = requests.get(self.mURL, verify=False)
                print(res.text)
                return res.text
            except Exception as e:
                print(e)
        return None
    #生成自已的公私钥对
    def createGhostKey(self):
        # 伪随机数生成器
        # random_generator = Random.new().read
        # rsa算法生成实例
        # rsa = RSA.generate(1024, random_generator)


        # # ghost的秘钥对的生成
        # #私钥
        # self.gprivate_pem = rsa.exportKey()
        # #公钥
        # self.gpublic_pem = rsa.publickey().exportKey()

        (self.gpublic_pem, self.gprivate_pem) = rsa.newkeys(1024)

    #使用交互方公钥加密消息数据
    def encryptWithMasterPubKey(self,msg,isBase64Out = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        if isBase64Out:
            cipher_text = base64.b64encode(rsa.encrypt(tmpmsg, self.mpublic_pem))
            return cipher_text
        else:
            dmsg = rsa.encrypt(tmpmsg, self.mpublic_pem)
            return dmsg

    def encryptWithPubKey(self,msg,pubpemkey,isBase64Out = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        if isBase64Out:
            cipher_text = base64.b64encode(rsa.encrypt(tmpmsg, pubpemkey))
            return cipher_text
        else:
            dmsg = rsa.encrypt(tmpmsg, pubpemkey)
            return dmsg

    #使用交互方公钥验证签名    
    def verifyWithMasterPubKey(self,msg,sign,isBase64In = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        if isBase64In:
            dmsg = base64.b64decode(tmpmsg)
        vermsg = rsa.verify(dmsg, sign, self.mpublic_pem)
        return vermsg

    #使用本地公钥加密消息数据
    def encryptWithGhostPubKey(self,msg,isBase64Out = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        if isBase64Out:
            cipher_text = base64.b64encode(rsa.encrypt(tmpmsg, self.gpublic_pem))
            return cipher_text
        else:
            dmsg = rsa.encrypt(tmpmsg, self.gpublic_pem)
            return dmsg

    #使用本地私钥解密消息
    def decryptWithGhostPriKey(self,msg,isBase64In = True):
        dmsg = msg
        if isBase64In:
            dmsg = base64.b64decode(msg)
        text = rsa.decrypt(dmsg, self.gprivate_pem)
        return text

    def enbase64(self,msg):
        dmsg = base64.b64encode(msg)
        return dmsg
    def debase64(self,msg):
        dmsg = base64.b64decode(msg)
        return dmsg
    #使用本地私钥签名消息
    def signWithGhostPriKey(self,msg):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        signature = rsa.sign(tmpmsg, self.gprivate_pem, 'SHA-1')
        return signature
    #使用本地公钥验证签名    
    def verifyWithGhostPubKey(self,msg,sign,isBase64In = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        dmsg = tmpmsg
        
        try:
            if isBase64In:
                dmsg = base64.b64decode(msg)
            vermsg = rsa.verify(dmsg, sign, self.gpublic_pem)
            return vermsg
        except Exception as e:
            return False
        

    #使用本地公钥验证签名    
    def verifyWithPubKey(self,msg,sign,pubpemkey,isBase64In = True):
        tmpmsg = msg
        if sys.version_info > (3,0):
            tmpmsg = msg.encode()
        dmsg = tmpmsg
        if isBase64In:
            dmsg = base64.b64decode(msg)
        vermsg = rsa.verify(dmsg, sign, pubpemkey)
        return vermsg




if __name__ == '__main__':
    pc = prpcrypt(mURL='', mkeyPth = '.', gkeyPth = '.',isCreateGkey = True)
    msg = 'abcdefg---001'
    pmsg = pc.encryptWithGhostPubKey(msg)
    omsg = pc.decryptWithGhostPriKey(pmsg)

    smsg = pc.signWithGhostPriKey(msg)
    b64msg = pc.enbase64(msg)
    vmsg = pc.verifyWithGhostPubKey(b64msg, smsg)

    print('msg--->',msg)
    print('pmsg-->',pmsg)
    print('omsg-->',omsg)
    print('smg-->',smsg)
    print('vmsg-->',vmsg)



#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: xingming
# Mail: huoxingming@gmail.com
# Created Time:  2015-12-11 01:25:34 AM
#############################################


from setuptools import setup, find_packages

setup(
    name = "insight2",
    version = "0.1.36",
    keywords = ("pathtool","timetool", "magetool", "mage"),
    description = "time and path tool",
    long_description = "time and path tool",
    license = "MIT Licence",

    author = "ark1ee",
    author_email = "ark1ee@ark.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ['chardet']
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import time
import threading
from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler


datatool = None


class TestHTTPHandler(BaseHTTPRequestHandler):

    def do_GET(self):
        print self.path
        print self.client_address
        global datatool
        try:
            if self.path[0:3] != '/bitmex':
                jobj = {'value':1}
                jstr = json.dumps(jobj)
                self.sendJsonMsg(jstr)
                return None
            else:
                self.send_error(404,'File Not Found: %s' % self.path) 
                return None
        except Exception as e:
            self.send_error(404,'File Not Found: %s' % self.path)  
            return None
        
    def sendJsonMsg(self,jmsg):
        length = len(jmsg)
        self.send_response(200)
        self.send_header("Content-type", 'application/json; encoding=utf-8')
        self.send_header("Content-Length", str(length))
        self.end_headers()
        self.wfile.write(jmsg)
    def do_POST(self):


        dictmp = self.do_GET()


        # length = self.headers.getheader('content-length');
        print(self.headers.headers())



        """Serve a POST request."""
        # form = cgi.FieldStorage(
        #     fp=self.rfile,
        #     headers=self.headers,
        #     environ={'REQUEST_METHOD': 'POST',
        #              'CONTENT_TYPE': self.headers['Content-Type'],
        #              })
        # filename = form['file'].filename
        # print filename
        # path = self.translate_path(self.path)
        # print path
        # filepath = os.path.join(path, filename)
        # print filepath
        # if os.path.exists(filepath):
        #     self.log_error('File %s exist!', filename)
        #     filepath += '.new'

        # with open(filepath, 'wb') as f:
        #     f.write(form['file'].value)

        

    def do_HEAD(self):
        """Serve a HEAD request."""
        f = self.send_head()
        if f:
            f.close()

def runHttpServer(port,objtool):
    global datatool
    datatool = objtool
    print(datatool)
    http_server = HTTPServer(('127.0.0.1', int(port)), TestHTTPHandler)
    print('server is start:(127.0.0.1,%d)'%(port))
    http_server.serve_forever() #设置一直监听并接收请求

def start_server(port):
    thr = threading.Thread(target=runHttpServer,args=(port,'xxx'))
    thr.setDaemon(True)
    thr.start()

def main():
    start_server(8889)

    while True:
        time.sleep(10)
        # print('sleep2')

if __name__ == '__main__':
    main()